C!*****************************************************************************
      SUBROUTINE PULVER
C-----******************************************************************
C-----*                                                                *
C-----*                                                                *
C-----*              P  U  L  V  E  R  I  X                            *
C-----*                                                                *
C-----*                                                                *
C-----******************************************************************
C-----*                                                                *
C-----* ROUTINE TO CALCULATE THEORETICAL POWDER PATTERNS               *
C-----* USING THE DATA FILE PREPARED BY  L  A  Z  Y                    *
C-----*                                                                *
C-----* AUTHORS                                                        *
C-----* K.YVON, W.JEITSCHKO  AND E.PARTHE                              *
C-----*                                                                *
C-----* ADDRESS                                                        *
C-----* LABORATOIRE DE CRISTALLOGRAPHIE AUX RAYONS X                   *
C-----* UNIVERSITY OF GENEVA                                           *
C-----* 24 QUAI ERNEST ANSERMET , CH 1211 GENEVE, SWITZERLAND          *
C-----* TEL  022 219355                                                *
C-----*                                                                *
C-----******************************************************************
C-----*                                                                *
C-----* R E M A R K S    FOR ADAPTING THE PROGRAM                      *
C-----*                                                                *
C-----* THIS IS THE UNIVAC 1100 VERSION. IF YOU HAVE A CDC-COMPUTER    *
C-----* REPLACE ALL CARDS THAT ARE FOLLOWED  BY A CARD MARKED C-CDC    *
C-----*                                                                *
C-----* THE FOLLOWING PARAMETERS CAN BE CHANGED IN THE BEGINNING OF    *
C-----* THE SOURCE DECK , THE ACTUAL VALUES GIVEN TO THESE             *
C-----* PARAMETERS ARE IN PARENTHESES                                  *
C-----*                                                                *
C-----* ILU        INPUT UNIT FROM  L A Z Y   (11)                     *
C-----* IPR        LINE PRINTER (6)                                    *
C-----* iref	output file for reflections (1)			       *
C-----*                                                                *
C-----* LIMIT1     LIMIT ON NUMBER OF REFLECTIONS  (1000)              *
C-----*            DIMENSIONS TO BE CHANGED                            *
C-----*            Q,YH,YK,YL,THETA,SUMA,SUMB,VINT,STRU,FPLG,FMUL,     *
C-----*            AX,AY,BX,BY,IDE                                     *
C-----*                                                                *
C-----* LIMIT2     LIMITATION ON DIFFERENT KINDS OF ATOMS (8)          *
C-----*            DIMENSIONS TO BE CHANGED                            *
C-----*            NA,X,Y,Z,FNEUT,BTEMP,ELEMT,FOCCU,DELFR,DELFI,       *
C-----*            FMULT,FA,FB,FC,IDE                                  *
C-----*                                                                *
C-----* LIMIT3     LIMIT ON NUMBER OF ATOMS OF ONE KIND   (50)         *
C-----*            DIMENSIONS TO BE CHANGED                            *
C-----*            X,Y,Z,BTEMP,FOCCU,FMULT,IDE                         *
C-----*                                                                *
C-----* LIMIT4     LIMIT ON NUMBER OF EQUIVALENT POINTPOSITIONS (24)   *
C-----*            DIMENSIONS TO BE CHANGED    TS, FS                  *
C-----*                                                                *
C-----* DG1        D-SPACING OF REFLECTING PLANES OF MONOCHROMATOR     *
C-----*            IN GUINIER CAMERA 1 (3.343)   QUARZ                 *
C-----*                                                                *
C-----* DG2        D-SPACING OF REFLECTING PLANES OF MONOCHROMATOR     *
C-----*            IN GUINIER CAMERA 2 (3.343)   QUARZ                 *
C-----*                                                                *
C-----* DM1        DIAMETER OF GUINIER CAMERA 1 IN MM (114.6)          *
C-----* BG1        ANGLE BETWEEN NORMAL TO THE SPECIMEN AND INCIDENT   *
C-----*            BEAM FOR CAMERA 1 (30 DEGREES)                      *
C-----*                                                                *
C-----* DM2        DIAMETER OF GUINIER CAMERA 2 IN MM (100.0)          *
C-----* BG2        ANGLE BETWEEN NORMAL TO THE SPECIMEN AND INCIDENT   *
C-----*            BEAM FOR CAMERA 2 (30 DEGREES)                      *
C-----* DD1        D-SPACING OF REFLECTING PLANES IN MONOCHROMATOR FOR
C-----*            POWDER-DIFFRACTOMETER (3.354)
C-----* GUINIER CAMERA 1  CORRESPONDS TO THE MODEL GUINIER-DE WOLFFII  *
C-----* MANUFACTURED BY ENRAF NONIUS DELFT    (*GUINIER NONIUS*)       *
C-----* GUINIER CAMERA 2  CORRESPONDS TO THE MODEL XDC-700 MANUFACTURED*
C-----* BY IRD COMPANY SWEDEN                 (*GUINIER-HAEGG*)        *
C-----*                                                                *
C-----******************************************************************
      DOUBLE PRECISION PI2,ARG,SMA,SMB,SUMA,SUMB,STRU,PRPINT
      DIMENSION Q(1000), YH(1000), YK(1000), YL(1000), THETA(1000), SUMA
     1(1000), SUMB(1000), VINT(1000), NA(8), X(50,8), Y(50,8), Z(50,8),
     2FNEUT(8), BTEMP(50,8), ELEMT(8), IPLA(100), COMPND(19), SP(900), W
     3(900), FOCCU(50,8), STRU(1000), FPLG(1000), FMUL(1000), DELFR(8),
     4DELFI(8), FMULT(50,8), IDT(9), IDL(34), TS(3,24), FS(3,3,24), FA(4
     5,8), FB(4,8), FC(8), AX(1000), AY(1000), BX(1000), BY(1000), IDE(5
     60,8), ITIT(13), NT(36), JB(21)
      COMMON /LIMITS/ LIMIT1,LIMIT2,LIMIT3,LIMIT4
      COMMON /UNITS/ ICR,IPR,ILU
      COMMON /EQUO/ TS,FS,NS,ISYMCE,IBRAVL
! the following data statements are reformatted
      DATA ITIT(1)/4H FOL/,ITIT(2)/4HLOWS/,ITIT(3)/4H OMI/,
     1 ITIT(4)/4HTTED/,ITIT(5)/3H MM/,ITIT(6)/3H   /,ITIT(7)/3H2TH/,
     2 ITIT(8)/3HETA/,ITIT(9)/4H NOT/,ITIT(10)/4HLOW /,
     3 ITIT(11)/4HHIGH/,ITIT(12)/2HNO/,ITIT(13)/2H A/
      DATA JB(1)/4HPRIM/,JB(2)/4HITIV/,JB(3)/4HE   /,JB(4)/4HBODY/,
     1 JB(5) /4H CEN/,JB(6) /4HTRED/,JB(7) /4HRHOM/,JB(8) /4HBOHE/,
     2 JB(9) /4HDRAL/,JB(10)/4HFACE/,JB(11)/4H CEN/,JB(12)/4HTRED/,
     3 JB(13)/4HA -C/,JB(14)/4HENTR/,JB(15)/4HED  /,JB(16)/4HB -C/,
     4 JB(17)/4HENTR/,JB(18)/4HED  /,JB(19)/4HC -C/,JB(20)/4HENTR/,
     5 JB(21)/4HED  /
      DATA ISTA/1H*/,IBLNK/1H /
      DATA IDT(1)/1H1/,IDT(2)/1H2/,IDT(3)/1H3/,IDT(4)/1H4/,IDT(5)/1H5/,
     1 IDT(6)/1H6/,IDT(7)/1H7/,IDT(8)/1H8/,IDT(9)/1H9/
      DATA IDL(1)/4H DEB/,IDL(2)/4HYE S/,IDL(3)/4HCHER/,IDL(4)/4HRER /,
     1 IDL(5) /4H    /,IDL(6) /4HSPEC/,IDL(7) /4HIAL /,IDL(8) /4HWITH/,
     2 IDL(9) /4H LP=/,IDL(10)/4H1   /,IDL(11)/4H NEU/,IDL(12)/4HTRON/,
     3 IDL(13)/4H DIF/,IDL(14)/4HFRAC/,IDL(15)/4HTION/,IDL(16)/4H    /,
     4 IDL(17)/4H GUI/,IDL(18)/4HNIER/,IDL(19)/4H CAM/,IDL(20)/4HERA /,
     5 IDL(21)/4H GUI/,IDL(22)/4HNIER/,IDL(23)/4H CAM/,IDL(24)/4HERA /,
     6 IDL(25)/4H    /,IDL(26)/4H DIF/,IDL(27)/4HFRAC/,IDL(28)/4HTOME/,
     7 IDL(29)/4HTER /,IDL(30)/4HWITH/,IDL(31)/4H MON/,IDL(32)/4HOCHR/,
     8 IDL(33)/4HOMAT/,IDL(34)/4HOR  /
	data iref/1/		! output reflection file unit
C-----
C-----CHANGE THE FOLLOWING PARAMETERS IF NECESSARY
C-----
C     ICR=5
C     IPR=6
C-CDC-IPR=61
C     ILU=11
C-CDC-ILU=51
      DG1=3.343
      DG2=3.343
      DM1=114.59156
      DM2=100.
      BG1=30.
      BG2=30.
! this is the monochromator d-spacing (DD1)
      DD1=3.354
C-----
C-----END OF PARAMETERS
C-----
      NFI=0
      PI2=6.283185307179586D0
      E=2.7182818
      FRTD=4./3.
C-----READ INPUT FROM BINARY DATA FILE ILU
      REWIND ILU
C-----READ NUMBER OF FILES ON ILU
      READ (ILU,END=9977) NFIL
      WRITE (IPR,138)
 1    NFI=NFI+1
      WRITE (IPR,141)
      IF (NFI.LE.NFIL) GO TO 2
      WRITE (IPR,139)
      GO TO 137
 2    READ (ILU,END=9977)
     1  (COMPND(I),I=1,19),A,B,C,ALPHA,BETA,GAMMA,WL,(NT(I),I=1
     1  ,36),IGROUP, IWL, ILP
      IF (A.GT.0.) GO TO 3
      WRITE (IPR,140) NFI
      GO TO 1
 3    READ (ILU,END=9977)
     1  ISYSTM,ISYMCE,IBRAVL,NS,TL,TH,NORM,IMAGE,ANO,KODLP,NCOM
     1  PO,(NA(I),I=1,8),IHOO,IOKO,IOOL,IHHL,IHOL,IHKO,IOKL,LAUE
      IF (NS.GT.LIMIT4) GO TO 136
      IF (NCOMPO.GT.LIMIT2) GO TO 134
      READ (ILU,END=9977) ((TS(I,II),(FS(K,I,II),K=1,3),I=1,3),II=1,NS)
      DO 4 M=1,NCOMPO
      NL=NA(M)
      IF (NL.GT.LIMIT3) GO TO 135
      READ (ILU,END=9977) DELFR(M),DELFI(M)
      READ (ILU,END=9977)
     1       ELEMT(M),(FA(I,M),FB(I,M),I=1,4),FC(M),FNEUT(M)
      READ (ILU,END=9977)
     1       (ELEMT(M),IDE(I,M),X(I,M),Y(I,M),Z(I,M),FMULT(I,M),FOCC
     1       U(I,M),BTEMP(I,M),I=1,NL)
 4    CONTINUE
C-----SET VARIABLES BACK TO ORIGINAL VALUE
      WRITE (IPR,142) NFI
C-----PRINT FIRST LINE OF TITLE
      VMXINT=0
      NLINE=0
      N=0
      ICON=0
      DUM=1.
      BGUIN=BG1
      DGU=DG1
C-----
      K=KODLP+1
      IF (KODLP.EQ.-1) K=1
      GO TO (7,7,7,5,6), K
C-----GUINIER NONIUS GEOMETRY
 5    DURCHM=DM1
      GO TO 7
C-----GUINIER HAEGG  GEOMETRY
 6    DURCHM=DM2
      BGUIN=BG2
      DGU=DG2
C-----CALCULATE CORRECTION TERM FOR LP FACTOR
 7    AGUIN=(1-WL*WL/(2.*DGU*DGU))**2.
      AMON=(1-WL*WL/(2.*DD1*DD1))**2.
C-----MULTIPLICITY FOR BRAVAIS LATTICE
      FBRA=IBRAVL
      IF (FBRA.GT.4.) FBRA=2.
C-----MULTIPLIER IF CENTER OF SYMMETRY AT ORIGIN
      IF (ISYMCE.NE.0) DUM=2.
C-----CALCULATE SIN**2 THETA LIMITS
      SH=TH*PI2/360.
      SL=TL*PI2/360.
      SH=(SIN(SH))**2
      SL=(SIN(SL))**2
C-----PRINT TITLE
      WRITE (IPR,165) COMPND
      WLSQ4=WL**2/4.
      ASTAR=WLSQ4/A**2
      IF ((ISYSTM.EQ.1).OR.(ISYSTM.EQ.2).OR.(ISYSTM.EQ.7)) BSTAR=WLSQ4/B
     1**2
      IF (ISYSTM.NE.5) CSTAR=WLSQ4/C**2
      BET=BETA*PI2/360.
      SINB2=(SIN(BET))**2
      COSB=COS(BET)
C-----TRICLINIC CASE
      IF (ISYSTM.NE.7) GO TO 8
      ALPH=ALPHA*PI2/360.
      GAMM=GAMMA*PI2/360.
      SV=(ALPH+BET+GAMM)/2.
      VOL=2.*A*B*C*SQRT(SIN(SV)*SIN(SV-ALPH)*SIN(SV-BET)*SIN(SV-GAMM))
      AST=(B*C*SIN(ALPH))/VOL
      BST=(A*C*SIN(BET))/VOL
      CST=(A*B*SIN(GAMM))/VOL
      COAST=(COSB*COS(GAMM)-COS(ALPH))/(SIN(BET)*SIN(GAMM))
      COBST=(COS(GAMM)*COS(ALPH)-COSB)/(SIN(GAMM)*SIN(ALPH))
      COGST=(COS(ALPH)*COSB-COS(GAMM))/(SIN(ALPH)*SIN(BET))
C-----START LOOP TO FIND HKL LIMITS FOR GIVEN SL AND SH LIMITS
 8    ZH=0.
      ZK=0.
      ZL=0.
 9    ZH=ZH+1.
      GO TO (10,15,16,21,22,23,24), ISYSTM
C-----MONOCLINIC
 10   ZHTEST=(2.0*A*SQRT(SH))/WL
      IF (ZH.LE.ZHTEST) GO TO 13
      ZH=0.
      ZK=ZK+1.
      ZKTEST=(2.0*B*SQRT(SH))/WL
      IF (ZK.LE.ZKTEST) GO TO 10
      ZK=0.
      IF (ICON.EQ.0) GO TO 11
      ZL=ZL-1.
      GO TO 12
 11   ZL=ZL+1.
 12   ZLTEST=(2.0*C*SQRT(SH))/WL
      IF (ABS(ZL).LE.ZLTEST) GO TO 10
      IF (ICON.EQ.1) GO TO 14
      ICON=1
      GO TO 8
 13   ATEST=ASTAR*ZH**2/SINB2+BSTAR*ZK**2+CSTAR*ZL**2/SINB2-WLSQ4*2.*ZH*
     1ZL*COSB/(A*C*SINB2)
      IF (ATEST.GT.SH) GO TO 9
      IF ((ICON.EQ.0).OR.((ZH.GT.0.9).AND.(ZL.LT.(-0.9)))) GO TO 31
      GO TO 9
 14   WRITE (IPR,187)
      WRITE (IPR,168) A,B,C,BETA,WL
      GO TO 73
C-----ORTHORHOMBIC
 15   ATEST=ASTAR*ZH**2+BSTAR*ZK**2+CSTAR*ZL**2
      IF (ATEST.LE.SH) GO TO 31
      ZH=0.
      ZK=ZK+1.
      BTEST=BSTAR*ZK**2+CSTAR*ZL**2
      IF (BTEST.LE.SH) GO TO 15
      ZK=0.
      ZL=ZL+1.
      CTEST=CSTAR*ZL**2
      IF (CTEST.LE.SH) GO TO 15
      WRITE (IPR,189)
      WRITE (IPR,169) A,B,C,WL
      GO TO 73
C-----TRIGONAL
 16   ATEST=FRTD*ASTAR*(ZH**2+ZH*ZK+ZK**2)+CSTAR*ZL**2
      IF ((ZH.EQ.0.).AND.(ZL.EQ.0.)) GO TO 9
      IF (ATEST.LE.SH) GO TO 19
      ZH=0.
      ZK=ZK+1.
      BTEST=FRTD*ASTAR*ZK**2+CSTAR*ZL**2
      IF (BTEST.LE.SH) GO TO 16
      ZK=0.
      IF (ICON.EQ.0) GO TO 17
      ZL=ZL-1.
      GO TO 18
 17   ZL=ZL+1.
 18   CTEST=CSTAR*ZL**2
      IF (CTEST.LE.SH) GO TO 16
      IF (ICON.EQ.1) GO TO 20
      ICON=1
      GO TO 8
 19   IF ((ICON.EQ.0).OR.((ZL.LT.(-0.9)).AND.((ZH.NE.0.).AND.(ZK.NE.0.))
     1)) GO TO 31
      GO TO 9
 20   WRITE (IPR,190)
      GO TO 72
C-----TETRAGONAL
 21   ATEST=ASTAR*(ZH**2+ZK**2)+CSTAR*ZL**2
      IF (ATEST.LE.SH) GO TO 31
      ZH=ZK+1.
      ZK=ZH
      BTEST=ASTAR*2.*ZH**2+CSTAR*ZL**2
      IF (BTEST.LE.SH) GO TO 21
      ZH=0.
      ZK=0.
      ZL=ZL+1.
      CTEST=CSTAR*ZL**2
      IF (CTEST.LE.SH) GO TO 21
      WRITE (IPR,191)
      GO TO 72
C-----CUBIC
 22   ATEST=ASTAR*(ZH**2+ZK**2+ZL**2)
      IF (ATEST.LE.SH) GO TO 31
      ZH=ZK+1.
      ZK=ZH
      BTEST=ASTAR*(2.*ZH**2+ZL**2)
      IF (BTEST.LE.SH) GO TO 22
      ZH=ZL+1.
      ZK=ZH
      ZL=ZH
      CTEST=ASTAR*3.*ZH**2
      IF (CTEST.LE.SH) GO TO 22
      WRITE (IPR,192)
      WRITE (IPR,171) A,WL
      GO TO 73
C-----HEXAGONAL
 23   ATEST=FRTD*ASTAR*(ZH**2+ZH*ZK+ZK**2)+CSTAR*ZL**2
      IF (ATEST.LE.SH) GO TO 31
      ZH=ZK+1.
      ZK=ZH
      BTEST=FRTD*ASTAR*3.*ZH**2+CSTAR*ZL**2
      IF (BTEST.LE.SH) GO TO 23
      ZH=0.
      ZK=0.
      ZL=ZL+1.
      CTEST=CSTAR*ZL**2
      IF (CTEST.LE.SH) GO TO 23
      WRITE (IPR,193)
      GO TO 72
C-----TRICLINIC
 24   ZHTEST=(2.0*A*SQRT(SH))/WL
      IF (ZH.LE.ZHTEST) GO TO 29
      ZH=0.
      IF (ICON.LT.2) GO TO 25
      ZK=ZK-1.
      GO TO 26
 25   ZK=ZK+1.
 26   ZKTEST=(2.0*B*SQRT(SH))/WL
      IF (ABS(ZK).LE.ZKTEST) GO TO 24
      ZK=0.
      IF ((ICON.EQ.0).OR.(ICON.EQ.2)) GO TO 27
      ZL=ZL-1.
      GO TO 28
 27   ZL=ZL+1.
 28   ZLTEST=(2.0*C*SQRT(SH))/WL
      IF (ABS(ZL).LE.ZLTEST) GO TO 24
      ICON=ICON+1
      GO TO (8,8,8,30), ICON
 29   ATEST=WLSQ4*((ZH*AST)**2+(ZK*BST)**2+(ZL*CST)**2+2.*ZK*ZL*BST*CST*
     1COAST+2.*ZH*ZL*AST*CST*COBST+2.*ZH*ZK*AST*BST*COGST)
      IF (ATEST.GT.SH) GO TO 9
      IF (ICON.EQ.0) GO TO 31
      IF (((ZH.EQ.0.).AND.(ZK.EQ.0.)).OR.((ZK.EQ.0.).AND.(ZL.EQ.0.)).OR.
     1((ZH.EQ.0.).AND.(ZL.EQ.0.))) GO TO 9
      IF ((ICON.EQ.1).AND.(ZL.LT.(-0.9))) GO TO 31
      IF (((ICON.EQ.2).AND.(ZK.LT.(-0.9))).AND.(ZH.GT.0.9)) GO TO 31
      IF ((ICON.EQ.3).AND.((ZH*ZK*ZL).NE.0.)) GO TO 31
      GO TO 9
C-----PRINT TRICLINIC LATTICE CONSTANTS
 30   WRITE (IPR,188)
      WRITE (IPR,172) A,B,C,ALPHA,BETA,GAMMA,WL
      GO TO 73
 31   IF (ATEST.LT.SL) GO TO 9
      XH=ZH
      XK=ZK
      XL=ZL
C-----OMIT HKL VALUES CORRESPONDING TO BRAVAIS LATTICE EXTINCTIONS
 32   GO TO (40,33,34,35,36,37,38), IBRAVL
 33   TESTBR=(XH+XK+XL)/2.
      GO TO 39
 34   TESTBR=(-XH+XK+XL)/3.
      GO TO 39
 35   FACEHK=(XH+XK)/2.
      IF ((AINT(FACEHK)-FACEHK).NE.0.) GO TO 9
 36   TESTBR=(XK+XL)/2.
      GO TO 39
 37   TESTBR=(XH+XL)/2.
      GO TO 39
 38   TESTBR=(XH+XK)/2.
 39   IF ((AINT(TESTBR)-TESTBR).NE.0.) GO TO 68
C-----OMIT HKL VALUES CORRESPONDING TO EXTINCTIONS
 40   IF (XL.EQ.0.) GO TO (41,50,49,50,47), IHKO
 41   IF (XH.EQ.0.) GO TO (42,54,53,54,51), IOKL
 42   IF (XK.EQ.0.) GO TO (43,58,57,58,55), IHOL
 43   IF (XH.EQ.XK) GO TO (44,59,61), IHHL
      IF ((XK.EQ.XL).AND.(ISYSTM.EQ.5)) GO TO (44,62,44,63), IHHL
 44   IF (XK.EQ.0..AND.XL.EQ.0.) GO TO (45,64,133,64), IHOO
 45   IF (XH.EQ.0..AND.XL.EQ.0.) GO TO (46,65,133,65), IOKO
 46   IF (XH.EQ.0..AND.XK.EQ.0.) GO TO (67,66,66,66,133,66), IOOL
      GO TO 67
 47   FIHKO=XH/2.
 48   IF (AINT(FIHKO)-FIHKO) 68,41,68
 49   FIHKO=XK/2.
      GO TO 48
 50   HKO=IHKO
      FIHKO=(XH+XK)/HKO
      GO TO 48
 51   FIOKL=XK/2.
 52   IF (AINT(FIOKL)-FIOKL) 68,42,68
 53   FIOKL=XL/2.
      GO TO 52
 54   OKL=IOKL
      FIOKL=(XK+XL)/OKL
      GO TO 52
 55   FIHOL=XH/2.
 56   IF (AINT(FIHOL)-FIHOL) 68,43,68
 57   FIHOL=XL/2.
      GO TO 56
 58   HOL=IHOL
      FIHOL=(XH+XL)/HOL
      GO TO 56
 59   FIHHL=XL/2.
 60   IF (AINT(FIHHL)-FIHHL) 68,44,68
 61   FIHHL=(2.*XH+XL)/4.
      GO TO 60
 62   FIHHL=XH/2.
      GO TO 60
 63   FIHHL=(2.*XL+XH)/4.
      GO TO 60
 64   HOO=IHOO
      FIHOO=XH/HOO
      IF (AINT(FIHOO)-FIHOO) 68,45,68
 65   FIOKO=XK/2.
      IF (AINT(FIOKO)-FIOKO) 68,46,68
 66   OOL=IOOL
      FIOOL=XL/OOL
      IF ((AINT(FIOOL)-FIOOL).NE.0.) GO TO 68
C-----STORE HKL AND SIN2THETA VALUES OF F VALUES  TO BE CALCULATED
 67   N=N+1
C-----CHECK IF NUMBER OF REFLECTIONS TOO LARGE
      IF (N.GT.LIMIT1) GO TO 132
      Q(N)=ATEST
      YH(N)=XH
      YK(N)=XK
      YL(N)=XL
      JJ=N
      J=JJ-1
C-----SKIP REFLECTIONS RELATED BY LAUE SYMMETRY
 68   IF ((LAUE.EQ.2).OR.(ZH.EQ.XK)) GO TO 9
      GO TO (9,9,9,69,70,69,9), ISYSTM
 69   IF ((ZH.GT.ZK).AND.(ZK.GT.0.)) GO TO 71
      GO TO 9
 70   IF ((ZH.GT.ZK).AND.(ZK.GT.ZL)) GO TO 71
      GO TO 9
 71   TEMP=XH
      XH=XK
      XK=TEMP
      GO TO 32
C-----PRINT HEX AND TETRAG LATTICE CONSTANTS, END OF HKL GENER.LOOP
 72   WRITE (IPR,170) A,C,WL
 73   IF (KODLP.EQ.-1) GO TO 730
      MP=KODLP*5+1
      KK=MP+4
      WRITE (IPR,173) TL,TH,(IDL(I),I=MP,KK)
 730  WRITE (IPR,173) TL,TH,(IDL(I),I=26,34)
C-----CHECK IF NUMBER OF REFLECTIONS TOO LARGE
      IF(N.GT.LIMIT1) GO TO 132
C-----PRINT DIFFRACTION GEOMETRY
      IF (KODLP.GT.2) WRITE (IPR,143) DURCHM,BGUIN,DGU
C-----PRINT SPACE GROUP AND EQUIVALENT POSITIONS
      N=6
      IF (IGROUP.EQ.0) N=9
      WRITE (IPR,144) ITIT(N),(NT(I),I=1,36)
      CALL EQUI
C-----PRINT LAUE SYMMETRY
      IF (ISYSTM.LT.3) GO TO 74
      N=10
      IF (LAUE.EQ.2) N=11
      WRITE (IPR,145) ITIT(N)
 74   N=12
C-----PRINT SYMMETRY CENTER
      IF (ISYMCE.EQ.1) N=13
      WRITE (IPR,146) ITIT(N)
C-----PRINT BRAVAIS LATTICE AND EXTINCTIONS
      N=IBRAVL*3-2
      WRITE (IPR,147) JB(N),JB(N+1),JB(N+2)
      WRITE (IPR,148)
      IF(IBRAVL.EQ.1) WRITE(IPR,208)
      IF(IBRAVL.EQ.2) WRITE(IPR,213)
      IF(IBRAVL.EQ.3) WRITE(IPR,214)
      IF(IBRAVL.EQ.4) WRITE(IPR,212)
      IF(IBRAVL.EQ.5) WRITE(IPR,209)
      IF(IBRAVL.EQ.6) WRITE(IPR,215)
      IF(IBRAVL.EQ.7) WRITE(IPR,211)
      IF ((IHKO.EQ.2).OR.(IHKO.EQ.4)) WRITE (IPR,176) IHKO
      IF (IHKO.EQ.3) WRITE (IPR,175)
      IF (IHKO.EQ.5) WRITE (IPR,174)
      IF ((IOKL.EQ.2).OR.(IOKL.EQ.4)) WRITE (IPR,178) IOKL
      IF (IOKL.EQ.3) WRITE (IPR,210)
      IF (IOKL.EQ.5) WRITE (IPR,177)
      IF ((IHOL.EQ.2).OR.(IHOL.EQ.4)) WRITE (IPR,181) IHOL
      IF (IHOL.EQ.3) WRITE (IPR,180)
      IF (IHOL.EQ.5) WRITE (IPR,179)
      IF (IHHL.EQ.2) WRITE (IPR,182)
      IF (IHHL.EQ.3) WRITE (IPR,183)
      IF (IHOO.GT.1) WRITE (IPR,184) IHOO
      IF (IOKO.GT.1) WRITE (IPR,185)
      IF (IOOL.GT.1) WRITE (IPR,186) IOOL
C-----PRINT NUMBER AND KINDS OF ATOMS IN UNIT CELL
      WRITE (IPR,196)
C-----NUMBER OF GENERAL POINT POSITIONS
      GEN=DUM*NS*FBRA
      DO 75 M=1,NCOMPO
      NL=NA(M)
      DO 75 I=1,NL
C-----NUMBER OF SPECIAL POINT POSITIONS
      FMULI=GEN*FMULT(I,M)
      SATO=FMULI*FOCCU(I,M)
 75   WRITE (IPR,197) ELEMT(M),IDE(I,M),FMULI,FOCCU(I,M),SATO
C-----CALCULATE NUMBER OF ELECTRONS AND PRINT X RAY SCATTERING FACTORS
      WRITE (IPR,149)
      SATO=0
      DO 78 M=1,NCOMPO
      IF (KODLP.NE.2) GO TO 76
C-----PRINT NEUTRON SCATTERING LENGTH
!      WRITE (IPR,150) ELEMT(M),FNEUT(M)
      WRITE(IPR,150)(ELEMT(N),FNEUT(N),N=1,NCOMPO)                              
      GO TO 79
 76   FSCAT=0.
      DO 77 I=1,4
      FSCAT=FSCAT+FA(I,M)
 77   CONTINUE
      INEL=FSCAT+FC(M)+0.1
      WRITE (IPR,151) ELEMT(M),(FA(I,M),FB(I,M),I=1,4),FC(M),INEL
      WRITE (IPR,152) DELFR(M),DELFI(M)
C-----CALCULATE F(000)
      NL=NA(M)
      DO 278 I=1,NL
 278  SATO=SATO+GEN*INEL*FMULT(I,M)*FOCCU(I,M)
 78   CONTINUE
C-----INDICATE ANOMALOUS DISPERSION CORRECTION
      IF (ANO.EQ.0.)WRITE (IPR,153)
      IF (ANO.NE.0.)WRITE (IPR,154)
      IFOO=SATO*(ABS(SATO)+0.5)/SATO
C-----WRITE F(000)
      IF (KODLP.NE.2) WRITE (IPR,155) IFOO
C-----PRINT ATOM POSITIONS
 79   WRITE (IPR,198)
      DO 80 M=1,NCOMPO
      NL=NA(M)
C-----PRINT ATOM COORDINATES
      WRITE (IPR,199) (ELEMT(M),IDE(I,M),X(I,M),Y(I,M),Z(I,M),FMULT(I,M)
     1,FOCCU(I,M),BTEMP(I,M),I=1,NL)
 80   CONTINUE
C-----EXIT IF NUMBER OF REFLECTIONS LESS THAN TWO
      IF(J.LE.1) GO TO 206
C-----START ORDERING REFLEXIONS
      DO 81 N=1,J
      NN=N+1
      DO 81 M=NN,JJ
      IF ((Q(N)-Q(M)).LE.0.) GO TO 81
      TEMP=Q(N)
      Q(N)=Q(M)
      Q(M)=TEMP
      TEMP=YH(N)
      YH(N)=YH(M)
      YH(M)=TEMP
      TEMP=YK(N)
      YK(N)=YK(M)
      YK(M)=TEMP
      TEMP=YL(N)
      YL(N)=YL(M)
      YL(M)=TEMP
C-----END OF ORDERING
 81   CONTINUE
C-----START LOOP TO CALCULATE F FOR ALL STORED REFLEXIONS
      DO 107 N=1,JJ
      IF (Q(N).GT.1.)GO TO 133
      THETA(N)=57.29578*ATAN(SQRT(Q(N)/(1.-Q(N))))
C-----CALCULATE LORENTZ POLARISATION FACTORS
      VV=THETA(N)*0.0174533
      SX2=(SIN(VV)/WL)**2
      PLG=1.
      IF (KODLP.NE.-1) GO TO 801
      PLG=(1.+(1.-2.*Q(N))**2 *AMON)/((1.+AMON)*Q(N)*SQRT(1.-Q(N)))
 801  IF (KODLP.EQ.0) PLG=(1.+(1.-2.*Q(N))**2)/(2.*Q(N)*SQRT(1.-Q(N)))
! replace the above statement for synchrotron data with the one below
! 801  IF (KODLP.EQ.0) PLG=1./(Q(N)*SQRT(1.-Q(N)))
      IF (KODLP.EQ.2) PLG=1./(Q(N)*SQRT(1.-Q(N)))
      WW=(2.*THETA(N)-BGUIN)*0.0174533
      IF (KODLP.GT.2) PLG=(1.+(1.-2.*Q(N))**2 *AGUIN)/((1.+AGUIN)*Q(N)*S
     1QRT(1.-Q(N))*COS(WW))
C-----CALCULATE MULTIPLICITY FOR POWDERLINE
      GO TO (82,84,87,89,91,93,96), ISYSTM
 82   IF ((YK(N).EQ.0.).OR.((YH(N).EQ.0.).AND.(YL(N).EQ.0.))) GO TO 96
 83   FMULTI=4.0
      GO TO 98
 84   IF (YH(N).EQ.0.) IF (YK(N)) 133,96,86
      IF (YK(N).EQ.0.) GO TO 86
      IF (YL(N).EQ.0.) GO TO 83
 85   FMULTI=8.0
      GO TO 98
 86   IF (YL(N)) 133,96,83
 87   IF ((YH(N).EQ.0.).AND.(YK(N).EQ.0.)) GO TO 96
 88   FMULTI=6.0
      GO TO 98
 89   IF ((YH(N)-YK(N)).EQ.0.) IF (YH(N)) 133,96,90
      IF (YK(N).EQ.0.) GO TO 90
      IF (YL(N).EQ.0.) IF (LAUE-1) 133,83,85
      IF (LAUE.EQ.1) GO TO 85
      FMULTI=16.
      GO TO 98
 90   IF (YL(N)) 133,83,85
 91   IF ((YH(N)-YK(N)).EQ.0.) IF (YL(N)) 133,97,92
      IF ((YL(N).EQ.0.).AND.(LAUE.EQ.2)) IF (YK(N)) 133,88,94
      IF ((YL(N).EQ.0.).AND.(LAUE.EQ.1)) IF (YK(N)) 133,88,97
      IF (((YK(N)-YL(N)).EQ.0.).OR.(LAUE.EQ.1)) GO TO 94
      FMULTI=48.
      GO TO 98
 92   IF (YH(N)-YL(N)) 133,85,94
 93   IF ((YH(N)-YK(N)).EQ.0.) IF (YH(N)) 133,96,95
      IF (YK(N).EQ.0.) GO TO 95
      IF ((YL(N).EQ.0.).AND.(LAUE.EQ.1)) GO TO 88
      IF ((YL(N).EQ.0.).OR.(LAUE.EQ.1)) GO TO 97
 94   FMULTI=24.0
      GO TO 98
 95   IF (YL(N)) 133,88,97
 96   FMULTI=2.0
      GO TO 98
 97   FMULTI=12.0
 98   SUMA(N)=0.
      SUMB(N)=0.
      SUMBX=0.
      SUMAX=0.
C-----LOOP OVER DIFFERENT KINDS OF ATOMS
      DO 104 M=1,NCOMPO
      DELTF=DELFI(M)
      SMA=0.
      SMB=0.
      NL=NA(M)
C-----LOOP OVER ALL ATOMS OF ONE KIND
      DO 100 I=1,NL
C-----LOOP OVER EQUIVALENT POSITIONS
      DO 99 J=1,NS
      XN=TS(1,J)+FS(1,1,J)*X(I,M)+FS(2,1,J)*Y(I,M)+FS(3,1,J)*Z(I,M)
      YN=TS(2,J)+FS(1,2,J)*X(I,M)+FS(2,2,J)*Y(I,M)+FS(3,2,J)*Z(I,M)
      ZN=TS(3,J)+FS(1,3,J)*X(I,M)+FS(2,3,J)*Y(I,M)+FS(3,3,J)*Z(I,M)
      ARG=PI2*(YH(N)*XN+YK(N)*YN+YL(N)*ZN)
C-----INCLUDE OCCUPATION, MULTIPLICITY AND TEMPERATURE FACTOR
      SMA=SMA+DCOS(ARG)*FMULT(I,M)*FOCCU(I,M)*E**(-BTEMP(I,M)*SX2)
      IF (ISYMCE.EQ.1) GO TO 99
      SMB=SMB+DSIN(ARG)*FMULT(I,M)*FOCCU(I,M)*E**(-BTEMP(I,M)*SX2)
C-----END OF LOOP OVER EQUIVALENT POSITIONS
 99   CONTINUE
C-----END OF LOOP OVER ALL ATOMS OF ONE KIND
 100  CONTINUE
      IF (FNEUT(M).NE.0.)GO TO 102
C-----CALCULATE ATOMIC SCATT. FACTOR
      FSCAT=0.
      DO 101 I=1,4
      AR=-FB(I,M)*SX2
      FSCAT=FSCAT+FA(I,M)*EXP(AR)
 101  CONTINUE
C-----REAL PART OF SCATTERING FACTOR
      FSCAT=FSCAT+DELFR(M)+FC(M)
      GO TO 103
C-----NEUTRON SCATTERING LENGTH
 102  FSCAT=FNEUT(M)
C-----MULTIPLY WITH SCATTERING FACTOR AND STORE FOR OUTPUT
 103  SUMA(N)=SUMA(N)+SMA*FSCAT
      SUMB(N)=SUMB(N)+SMB*FSCAT
C-----CALCULATE IMAGINARY CORRECTION TERM FOR ANOMALOUS DISPERSION
      IF (ANO.EQ.0.)GO TO 104
      SUMAX=SUMAX+SMA*DELTF*FBRA*DUM
      SUMBX=SUMBX+SMB*DELTF*FBRA
C-----END OF LOOP OVER DIFFERENT KINDS OF ATOMS
 104  CONTINUE
C-----INCLUDE BRAVAIS MULTIPLICITY AND MULTIPLIER FOR CENTER AT ORIGIN
      SUMA(N)=FBRA*SUMA(N)*DUM
      SUMB(N)=FBRA*SUMB(N)
      FPLG(N)=PLG
      FMUL(N)=FMULTI
      IF (ANO.EQ.0.)GO TO 105
C-----CALCULATE TOTAL CORRECTION TERMS FOR ANOMALOUS DISPERSION
      FMULTI=FMULTI/2.
      AX(N)=SUMA(N)-SUMBX
      AY(N)=SUMA(N)+SUMBX
      BX(N)=SUMB(N)+SUMAX
      BY(N)=-SUMB(N)+SUMAX
      STRU(N)=SUMA(N)**2+SUMB(N)**2+SUMAX**2+SUMBX**2
      GO TO 106
 105  STRU(N)=SUMA(N)**2+SUMB(N)**2
 106  VINT(N)=PLG*FMULTI*STRU(N)
C-----FIND MAXIMAL INTENSITY FOR NORMALISATION TO 1000.
      VMXINT=AMAX1(VMXINT,VINT(N))
C-----END OF LOOP TO CALCULATE F FOR ALL STORED AND ORDERED HKL VALUES
 107  CONTINUE
C-----OUTPUT OF JJ LINES WITH REFLECTION DATA
      N=1
      IF (NORM.EQ.3) N=3
      WRITE (IPR,156) ITIT(N),ITIT(N+1)
C-----SKIP TABULAR LIST
      IF (NORM.EQ.3) GO TO 122
      WRITE (IPR,157)
      NLINE=55
      K=KODLP+1
      I=NORM+1
      DO 121 N=1,JJ
      IF (NLINE.NE.55) GO TO 115
C-----PRINT HEADING OF PAGES
      GO TO (110,109,108,122), I
 108  WRITE (IPR,200)
      GO TO 114
 109  WRITE (IPR,201)
      GO TO 114
C-----BNL CDC7600 WILL NOT ACCEPT K=0 IN COMPUTED GO TO STATEMENT
  110 IF(K.EQ.0) GO TO 112
      GO TO (112,112,112,111,111), K
 111  J=5
      GO TO 113
 112  J=7
 113  WRITE (IPR,202) ITIT(J),ITIT(J+1)
 114  NLINE=0
 115  CONTINUE
      IH=YH(N)
      IK=YK(N)
      IL=YL(N)
      M=FMUL(N)
      DVAL=WL/(2.*SQRT(Q(N)))
      THETA2=2.*THETA(N)
      IF (KODLP.GT.2) THETA2=THETA(N)*(DURCHM/28.64789)
      PRPINT=VINT(N)*1000./VMXINT
      VVV=Q(N)
      DSQ=1./(DVAL*DVAL)
      SUMAN=SUMA(N) +0.000001
      SUMBN=SUMB(N)
      STRU1=STRU(N)
      STRU1=SQRT(STRU1)
C-----ANOMALOUS DISPERSION FOR FRIEDEL PAIRS
      IF (ANO.EQ.0.)GO TO 116
      A1=AX(N) +0.000001
      A2=AY(N) +0.000001
      B1=BX(N)
      B2=BY(N)
      SUMBN=B1
      STRU1=A1*A1+B1*B1
      STRU2=A2*A2+B2*B2
      STRU1=SQRT(STRU1)
      STRU2=SQRT(STRU2)
      PHA1=(ATAN2(B1,A1))*360./PI2
      PHA2=(ATAN2(B2,A2))*360./PI2
 116  IF ((SUMAN.NE.0.).OR.(SUMBN.NE.0.)) PHANG=(ATAN2(SUMBN,SUMAN))*360
     1./PI2
      GO TO (117,118,119,121), I
 117  WRITE (IPR,203) IH,IK,IL,THETA(N),THETA2,DVAL,DSQ  ,Q(N),IH,IK,IL,
     1PRPINT,STRU1,SUMAN,SUMBN,PHANG,M,FPLG(N),N
      GO TO 120
 118  WRITE (IPR,204) IH,IK,IL,THETA(N),Q(N),PRPINT,VINT(N),STRU1,SUMAN,
     1SUMBN,PHANG,M,FPLG(N)
      GO TO 120
 119  WRITE (IPR,205) IH,IK,IL,THETA(N),THETA2,DVAL,Q(N),IH,IK,IL,PRPINT
     1,STRU1,STRU2,A1,A2,B1,B2,PHA1,PHA2,M,FPLG(N)
 120  NLINE=NLINE+1
	write (1,11111) 4,ih,ik,il,m
11111 format(5i8)
C-----END OF OUTPUT OF NUMERICAL VALUES
 121  CONTINUE
C-----GRAPHIC OUTPUT OF INTENSITIES
 122  N=3
      IF (IMAGE.EQ.0) GO TO 123
      N=1
      STEP=1./(2.*FLOAT(IMAGE))
 123  WRITE (IPR,158) ITIT(N),ITIT(N+1)
      IF (IMAGE.EQ.0) GO TO 1
      WRITE (IPR,159) STEP
      VMXINT=0.
C-----TAKE THIS STATEMENT OUT (GENEVA UNIVAC 1100 SPECIFIC)
C-----CALL HEAD (COMPND,NT,IWL,ILP)
C-----SUPPRESS PAGE JUMP  (CHANGE SUBROUTINE PAG IF NECESSARY )
C-----CALL PAG
      IF (KODLP.NE.-1) GO TO 1230
      WRITE (IPR,166) COMPND,WL,(IDL(I),I=26,34)
      GO TO 1231
 1230 WRITE (IPR,166) COMPND,WL,(IDL(I),I=MP,KK)
C-----FIRST THETA VALUE
 1231 W(1)= TL
C-----NUMBER OF INTERVALS
      KK=INT((TH-TL)/STEP + 1.)
C-----LOOP OVER ALL INTERVALS
      IF (KK.GT.LIMIT1) GO TO 1370
      DO 125 K=1,KK
      SP(K)=0.
      FMUL(K)=0.
      STRU(K)=0.
      IF (K.NE.1) W(K)=W(K-1)+STEP
      VMA=0.
      WK1=W(K)-0.5*STEP
      WK2=WK1+STEP
C-----LOOP OVER ALL REFLECTIONS IN ONE INTERVAL
      DO 124 N=1,JJ
      IF ((THETA(N).LT.WK1).OR.(THETA(N).GE.WK2)) GO TO 124
      VMA=AMAX1(VMA,VINT(N))
C-----STORE THE POINTER TO STRONGEST REFLECTION IN THIS INTERVAL
      IF (VMA.EQ.VINT(N)) FMUL(K)=FLOAT(N)
C-----ACCUMULATE COINCIDENT INTENSITIES IN EACH INTERVAL
      SP(K)=SP(K)+VINT(N)
C-----COUNT NUMBER OF COINCIDING REFLECTIONS
      STRU(K)=STRU(K)+1.
 124  CONTINUE
C-----FIND LARGEST SUM OF INTENSITIES AMONG ALL INTERVALS
      VMXINT=AMAX1(VMXINT,SP(K))
 125  CONTINUE
C-----FILL EACH OUTPUT LINE WITH STARS, BLANKS, DOTS ETC
      DO 131 K=1,KK
      IF (FMUL(K).EQ.0) GO TO 1250
      NSPIEL=SP(K)*100./(VMXINT)+.5
      NSP10=(NSPIEL-1)/10
      IF (NSP10.GT.9) NSP10=9
      N=FMUL(K)
      IH=YH(N)
      IK=YK(N)
      IL=YL(N)
 1250 CONTINUE
      I=STRU(K)
      DO 126 MP=1,100
      IPLA(MP)=IBLNK
      IF (W(K).EQ.0.) IPLA(MP)=ISTA
 126  CONTINUE
      IF (STRU(K).EQ.0) GO TO 130
      IF (NSPIEL.EQ.0) GO TO 129
      DO 127 MP=1,NSPIEL
 127  IPLA(MP)=ISTA
      IF (NSP10.LT.1) GO TO 129
      DO 128 J=1,NSP10
      MP=10*J
 128  IPLA(MP)=IDT(J)
C-----WRITE ONE LINE OF GRAPHICAL OUTPUT WITH HKL OF STRONGEST INTENS.
 129  WRITE (IPR,160) IH,IK,IL,I,W(K),(IPLA(MP),MP=1,100)
      GO TO 131
C-----WRITE ONE LINE OF GRAPHICAL OUTPUT WITHOUT HKL
 130  WRITE (IPR,167) W(K),(IPLA(MP),MP=1,100)
 131  CONTINUE
      WRITE (IPR,161)
C-CDC--TAKE THE FOLLOWING STATEMENT OUT (REINITIALIZES PAGE JUMP)
C-----THIS STATEMENT IS UNIVAC 1100 GENEVA SPECIFIC
      GO TO 1
C-----REDUCE UPPER THETA LIMIT AND TRY AGAIN
  132 TH1=TH-5.
      WRITE (IPR,195)  LIMIT1,TH,TH1
      IF(TH1.LE.SL) GO TO 206
      TH=TH1
      SH=TH*PI2/360.
      SH=(SIN(SH))**2
      ICON=0
      N=0
      GO TO 8
 133  WRITE (IPR,194)
      GO TO 1
 134  WRITE (IPR,162) NCOMPO
      GO TO 1
 135  WRITE (IPR,163) NL
      GO TO 1
 136  WRITE (IPR,164) NS
      GO TO 1
  206 WRITE(IPR,207)
      GO TO 1
 1370 WRITE (IPR,216) LIMIT1
      GO TO 1
C-CDC-CALL EXIT
C-----
 138  FORMAT (   ///,23H START  P U L V E R I X     )
 139  FORMAT (/39H B Y E  B Y E  L A Z Y  P U L V E R I X  )
 140  FORMAT (4H JOB  ,I5,40H IS BAD DUE TO ERROR IN PREVIOUS PROGRAM,/1
     16H GO TO NEXT JOB ,//)
 141  FORMAT (1H //////)
 142  FORMAT (4H1JOB,I5/ )
 143  FORMAT (/2X,9H DIAMETER,F9.4,3H MM,/2X,60H ANGLE BETWEEN NORMAL TO
     1 PLANE OF SPECIMEN AND INCIDENT BEAM,F7.2,5H DEG.,/2X,27H D-SPACIN
     2G OF MONOCHROMATOR,F7.3,9H ANGSTROM)
 144  FORMAT ( /12H SPACE GROUP,A4,22H GIVEN ON SPCGRP-CARD ,36A1)
 145  FORMAT (/1X,A4,14H LAUE SYMMETRY)
 146  FORMAT (/10H THERE IS ,A2,30H SYMMETRY CENTRE AT THE ORIGIN)
 147  FORMAT (/1X,3A4,16H BRAVAIS LATTICE)
 148  FORMAT ( /41H CONDITIONS LIMITING POSSIBLE REFLECTIONS  /)
 149  FORMAT (/ 32H SCATTERING FACTOR  COEFFICIENTS/   )
 150  FORMAT (/1X,A4,2X,3H F=,F6.3,6H CM-12/)
 151  FORMAT (1X,A4,9F9.5,/5X,21H NUMBER OF ELECTRONS=,I5,9X,
     X37H(CALCULATED USING ABOVE COEFFICIENTS))
 152  FORMAT (6X,6HDELFR=,F7.3,2X,6HDELFI=,F7.3,5X,40H (ANOMALOUS DISPER
     XSION CORRECTION TERMS)/)
 153  FORMAT ( /52H NO CORRECTION FOR ANOMALOUS DISPERSION WILL BE MADE)
 154  FORMAT ( /49H CORRECTION FOR ANOMALOUS DISPERSION WILL BE MADE)
 155  FORMAT (/ 45H NUMBER OF ELECTRONS IN UNIT CELL   F(0,0,0)=,I8)
 156  FORMAT (/// 1X,50(1H-),//41H - T A B U L A R  L I S T  OF INTENSIT
     1IES,2A4,2H -//1X,50(1H-))
 157  FORMAT (//20H THE COLUMNS CONTAIN//21H MILLER INDICES (HKL)/,20H B
     1RAGG ANGLE (THETA),/68H ANGLE (2THETA) OR THE DISTANCE IN MM OF A 
     2LINE FROM THE ORIGIN (MM),/25H D-VALUE AND/OR 1/D**2     /58H SQUA
     3RE OF SINE (THETA)  MULTIPLIED BY 1000 (SIN2*1000)   ,/91H INTENSI
     4TY OF A POWDER LINE, SCALED TO 1000 OR UNSCALED   (INTENSITY OR IN
     5TENSITY UNSCALED),/39H STRUCTURE FACTOR  (/F(HKL)/)          /60H 
     6REAL AND IMAGINARY PART OF STRUCTURE FACTOR (A(HKL),B(HKL)),/23H P
     7HASE ANGLE (PHA.ANG.)/40H MULTIPLICITY OF THE POWDER LINE (MULT) /
     899H LORENTZ-POLARISATION FACTOR FOR X RAY DIFFRACTION, OR LORENTZ 
     9FACTOR FOR NEUTRON DIFFRACTION (LPG) //94H THE EXACT NUMBER OF COL
     *UMNS DEPENDS ON THE INPUT VARIABLES SYMLP,NORM,IANO ON THE CONDIT 
     *CARD/97H IN THE CASE OF ANOMALOUS DISPERSION THE STRUCTURE FACTORS
     * AND PHASE ANGLES ARE LISTED SEPARATELY/90H FOR THE ANTIREFLECTION
     *S (/F+(HKL)/,/F-(HKL)/,A+(HKL),A-(HKL),B+(HKL),B-(HKL),PHA+,PHA-) 
     *///////)
 158  FORMAT (///1X,70(1H-),//,68H - G R A P H I C  R E P R E S E N T A 
     1T I O N  OF THE POWDER PATTERN ,2A4,2H -//1X,70(1H-))
 159  FORMAT (//46H THE POWDER PATTERN WILL BE GIVEN IN STEPS OF,F7.4   
     1,6H THETA//61H THE THETA VALUES INDICATED ARE THE CENTRES OF THE I
     2NTERVALS //50H EACH LINE CONTAINS FROM THE LEFT TO THE RIGHT    //
     392H THE MILLER INDICES OF THE STRONGEST REFLECTION CONTRIBUTING TO
     4 THE INTENSITY   ( H K L )   ,/     54H THE NUMBER OF REFLECTIONS 
     5FALLING IN THE INTERVAL (N) ,/56H THE THETA VALUE OF THE CENTER OF
     6 THE INTERVAL  (THETA) /92H THE INTENSITY OF THE SUM OF ALL REFLEC
     7TIONS FALLING IN THE INTERVAL (MAXIMUM=100 ASTERISKS))
 160  FORMAT (1HS,3I3,5X,I2,F8.2,1X,1H1,100A1,1H1)
CDC----1X  SHOULD BE REPLACED BY 1HS TO SUPPRESS PAGE JUMP
C-B6700 1H6 SUPPRESSES THE PAGE JUMP
 161  FORMAT (26X,102(1H-),///)
 162  FORMAT (22H NUMBER OF ATOM KINDS=,I5,10H TOO LARGE)
 163  FORMAT (29H NUMBER OF ATOMS OF ONE KIND=,I5,10H TOO LARGE)
 164  FORMAT (41H NUMBER OF SYMMETRY EQUIVALENT POSITIONS=,I5,
     1 ' TOO LARGE')
 165  FORMAT (/27H INTENSITY CALCULATION FOR ,19A4/)
 166  FORMAT (/26H1 DIFFRACTION PATTERN FOR ,18A4,A2,/4H WL=,F8.5,9A4//,
     12X,24HH  K  L       N   THETA ,102(1H-))
 167  FORMAT (1HS,16X,F8.2,1X,1H1,100A1,1H1)
CDC----1X  SHOULD BE REPLACED BY 1HS TO SUPPRESS PAGE JUMP
C-B6700 1H6 SUPPRESSES THE PAGE JUMP
 168  FORMAT(3H A=,F9.5/3H B=,F9.5/3H C=,F9.5/6H BETA=,F9.5/4H WL=,F8.5)
 169  FORMAT (3H A=,F9.5/3H B=,F9.5/3H C=,F9.5/4H WL=,F8.5/)
 170  FORMAT (3H A=,F9.5/3H C=,F9.5/4H WL=,F8.5)
 171  FORMAT (3H A=,F9.5/4H WL=,F8.5)
 172  FORMAT (3H A=,F9.5/3H B=,F9.5/3H C=,F9.5/7H ALPHA=,F9.5/6H BETA=,
     1F9.5/7H GAMMA=,F9.5/4H WL=,F8.5)
 173  FORMAT(/26H CALCULATION BETWEEN TL = ,F4.1,9H AND TH =,F6.1,
     116H DEGREES THETA  ,//23H DIFFRACTION GEOMETRY =,9A4)
 174  FORMAT (19H HKO WITH H=2N ONLY)
 175  FORMAT (19H HKO WITH K=2N ONLY)
 176  FORMAT (14H HKO WITH H+K=,I1,6HN ONLY)
 177  FORMAT (19H OKL WITH K=2N ONLY)
 210  FORMAT (19H OKL WITH L=2N ONLY)
 178  FORMAT (14H OKL WITH K+L=,I1,6HN ONLY)
 179  FORMAT (19H HOL WITH H=2N ONLY)
 180  FORMAT (19H HOL WITH L=2N ONLY)
 181  FORMAT (14H HOL WITH H+L=,I1,6HN ONLY)
 182  FORMAT (19H HHL WITH L=2N ONLY)
 183  FORMAT (22H HHL WITH 2H+L=4N ONLY)
 184  FORMAT (12H HOO WITH H=,I1,6HN ONLY)
 185  FORMAT (19H OKO WITH K=2N ONLY)
 186  FORMAT (12H OOL WITH L=,I1,6HN ONLY)
 187  FORMAT (/21H MONOCLINIC STRUCTURE)
 188  FORMAT (/20H TRICLINIC STRUCTURE)
 189  FORMAT (/23H ORTHORHOMBIC STRUCTURE)
 190  FORMAT (/19H TRIGONAL STRUCTURE)
 191  FORMAT (/21H TETRAGONAL STRUCTURE)
 192  FORMAT (/16H CUBIC STRUCTURE)
 193  FORMAT (/20H HEXAGONAL STRUCTURE)
 194  FORMAT(/53H SOMETHING VERY BAD HAPPENED. CALL THE AUTHORS PLEASE)
 195  FORMAT (/,' *OVERFLOW*',/' NUMBER OF REFLECTIONS IS GREATER THAN'
     1 ,I5,/' *** UPPER THETA LIMIT *** IS REDUCED FROM',F6.2,' TO ',
     2 F5.2/)
 196  FORMAT (/,' NUMBER OF ATOMS IN UNIT CELL'//,' ELEMENT NUMBER*  '
     1,'0CCUP=  NTOTAL')
 197  FORMAT (2X,A4,A2,F7.1,1H*,F7.3,1H=,F8.3)
 198  FORMAT (/' ATOM  POSITIONS'//,' ELEMENT   X/A     ',
     1 ' Y/B      Z/C    FMULT   OCCUP   BTEMP')
 199  FORMAT (1X,A4,A2,3F9.6,F7.4,F8.4,F7.3)
 200  FORMAT (1H1,131H H  K  L THETA  MM     D     SIN2   H  K  L INTENS
     1    F+(HKL)    F-(HKL)  A+(HKL)  A-(HKL)  B+(HKL)  B-(HKL) PHA+  P
     2HA- MULT   LPG /)
 201  FORMAT(/130H1 H  K  L    THETA  SIN2*1000 INT.SCALED   INTENSITY U
     1NSCALED           /F(HKL)/        A(HKL)        B(HKL) PHA.ANG. MU
     2LT    LPG   /)
 202  FORMAT(/18H1 H  K  L  THETA  ,2A3,108H D VALUE  1/D**2 SIN2*1000  
     1H  K  L INTENSITY       /F(HKL)/      A(HKL)      B(HKL) PHA.AN
     2G. MULT   LPG  NP/)
 203  FORMAT (3I3,2F7.2,F9.4,1X,F7.4,3PF9.2,1X,3I3,0PF10.1,0PF15.1,
     1 0P2F12.2,0PF8.2,I3,0PF7.2,I5)
 204  FORMAT (3I3,F9.2,3P1F10.2,0PF10.1,0PF22.1,0PF20.1,0P2F14.2,
     1 0PF8.2,I3,0PF8.2)
 205  FORMAT (3I3,2F6.1,F8.4,3PF6.1,3I3,0PF7.1,0P2F11.1,0P4F9.1,
     1 0P2F6.1,I3,F7.2)
 207  FORMAT(/,' * BAD LUCK *',/,
     1 ' ONLY ONE (OR NO) REFLECTION FALLS IN THE THETA RANGE SPECIFIED'
     2 ,/,' NO POWDER PATTERN WILL BE CALCULATED')
 208  FORMAT(10H HKL  NONE)
 209  FORMAT(21H HKL WITH K+L=2N ONLY)
 215  FORMAT(21H HKL WITH H+L=2N ONLY)
 211  FORMAT(21H HKL WITH H+K=2N ONLY)
 212  FORMAT(40H HKL WITH H,K,L ALL EVEN OR ALL ODD ONLY )
 213  FORMAT(23H HKL WITH H+K+L=2N ONLY)
 214  FORMAT(24H HKL WITH -H+K+L=3N ONLY)
 216  FORMAT(/13H * BAD LUCK */11H MORE THAN ,I4,7H STEPS /
     135H DECREASE "IMAGE" ON *CONDIT* CARD.)
 137  RETURN
9977  STOP 'ERROR IN PULVERIX--END OF FILE ON READ'
      END
C!*****************************************************************************
      SUBROUTINE EQUI
C-----PRINTS EQUIPOINTS STORED IN TS,FS,ISYMCE AND IBRAVL
      COMMON /EQUO/ TS,FS,NG,ISYMCE,IBRAVL
      COMMON /UNITS/ ICR,NPT,ILU
      INTEGER DIG,SYMB1,SYMB2
      DIMENSION TS(3,24), FS(3,3,24), CON1(7), SYMB1(8), SYMB2(9), DIG(1
     13), IB(24), IP(12), N3(9)
! reformated
      DATA IB(1)/4H1/2 /,IB(2)/4H2/3 /,IB(3)/4H1/2 /,IB(4)/4H 0  /,
     1 IB(5) /4H1/2 /,IB(6) /4H1/2 /,IB(7) /4H1/2 /,IB(8) /4H1/3 /,
     2 IB(9) /4H1/2 /,IB(10)/4H1/2 /,IB(11)/4H 0  /,IB(12)/4H1/2 /,
     3 IB(13)/4H1/2)/,IB(14)/4H1/3 /,IB(15)/4H 0, /,IB(16)/4H1/2)/,
     4 IB(17)/4H1/2)/,IB(18)/4H 0 )/,IB(19)/4H1/3 /,IB(20)/4H1/2 /,
     5 IB(21)/4H2/3 /,IB(22)/4H 0  /,IB(23)/4H2/3)/,IB(24)/4H1/2,/
      DATA CON1(1)/0.75/,CON1(2)/0.6667/,CON1(3)/0.5/,CON1(4)/0.3333/,CO
     1N1(5)/0.25/,CON1(6)/0.16667/,CON1(7)/0.83333/
      DATA SYMB1(1)/3H3/4/,SYMB1(2)/3H2/3/,SYMB1(3)/3H1/2/,SYMB1(4)/3H1/
     13/,SYMB1(5)/3H1/4/,SYMB1(6)/3H1/6/,SYMB1(7)/3H5/6/,SYMB1(8)/3H   /
      DATA SYMB2(1)/3H +X/,SYMB2(2)/3H  X/,SYMB2(3)/3H -X/,SYMB2(4)/3H +
     1Y/,SYMB2(5)/3H  Y/,SYMB2(6)/3H -Y/,SYMB2(7)/3H +Z/,SYMB2(8)/3H  Z/
     2,SYMB2(9)/3H -Z/
! reformated
      DATA N3(1)/1H /,N3(2)/3H   /,N3(3)/4H    /,N3(4)/1H,/,
     1 N3(5)/4H+(0 /,N3(6)/4H0 0,/,N3(7)/4H 0  /,N3(8)/4H1/2 /,
     2 N3(9)/4H1/2)/
      WRITE (NPT,15)
      DIG(13)=N3(1)
      IF (ISYMCE.EQ.1) DIG(13)=N3(4)
C-----FILL OUTPUT STRING WITH BLANKS
      DO 1 NN=1,12
      IP(NN)=N3(3)
 1    DIG(NN)=SYMB1(8)
C-----FILL OUTPUT STRING IP WITH BRAVAIS LATTICE VECTORS
      IF (IBRAVL.LT.2) GO TO 4
C-----FIRST VECTOR
      IP(1)=N3(5)
      IP(2)=N3(6)
C-----SECOND VECTOR
      DO 2 I=1,3
      I1=I+2
      I2=IBRAVL-1
      I3=I*6-6
 2    IP(I1)=IB(I2+I3)
      IF ((IBRAVL.LT.3).OR.(IBRAVL.GT.4)) GO TO 4
C-----THIRD VECTOR
      I2=16+IBRAVL
      DO 3 I=1,3
      I1=I+5
      I3=I*2-2
 3    IP(I1)=IB(I2+I3)
C-----FORTH VECTOR
      IF (IBRAVL.EQ.3) GO TO 4
      IP(9)=N3(7)
      IP(10)=N3(8)
      IP(11)=N3(9)
C-----LOOP OVER NUMBER OF EQUIPOINTS
 4    DO 14 I=1,NG
C-----FILL OUTPUT STRING WITH BLANKS
      DO 5 NN=1,12
 5    DIG(NN)=N3(2)
      ANTI=1.
      NN=1
C-----LOOP OVER X Y Z  COORDINATES
 6    DO 12 J=1,3
      TS1=ANTI*TS(J,I)
      IF (TS1.LT.0.) TS1=1.+TS1
      N1=1
      IF (TS1.EQ.0.) GO TO 9
      DO 7 II=1,7
      DIF=TS1-CON1(II)
      DIF=ABS(DIF)
      IF (DIF.LT..010) GO TO 8
 7    CONTINUE
      WRITE (NPT,16)
      RETURN
 8    DIG(NN)=SYMB1(II)
      NN=NN+1
      N1=2
 9    L=1
C-----LOOP OVER ROWS IN MATRIX
      DO 11 M1=1,3
      FS1=ANTI*FS(M1,J,I)
      IF (FS1.EQ.0.) GO TO 10
      IF (FS1.EQ.1.) L=L-N1+2
      IF (FS1.EQ.-1.) L=L+2
      N1=N1+1
      DIG(NN)=SYMB2(L)
      NN=NN+1
 10   L=M1*3+1
 11   CONTINUE
      NN=NN-N1+3
 12   CONTINUE
      IF (ANTI.EQ.-1.) GO TO 13
      ANTI=-1.
      IF (ISYMCE.EQ.1) GO TO 6
 13   WRITE (NPT,17) (DIG(I1),I1=1,6),DIG(7),DIG(8),DIG(13),DIG(9),DIG(1
     10),DIG(13),DIG(11),DIG(12),(IP(I1),I1=1,12)
 14   CONTINUE
      RETURN
C
 15   FORMAT (/27H EQUIVALENT POINT POSITIONS/)
 16   FORMAT (33H EQUIPOINT CODE BADLY INTERPRETED)
 17   FORMAT (1X,2(2A3,1H,),2A3,5X,2(2A3,A1),2A3,2X,12A4)
      END
